<?php
require_once '../includes/auth.php';
require_once '../includes/db.php';
require_once '../includes/functions.php';

// 验证管理员登录
if (!isLoggedIn()) {
    header("Location: ../login.php");
    exit;
}

// 验证ID参数
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    header("Location: manage.php");
    exit;
}

$id = (int)$_GET['id'];
$page_title = "编辑香烟数据";
$is_admin_page = true;

// 获取当前记录数据
try {
    $stmt = $pdo->prepare("SELECT * FROM cigarettes WHERE id = ?");
    $stmt->execute([$id]);
    $item = $stmt->fetch();
    
    if (!$item) {
        header("Location: manage.php");
        exit;
    }
} catch (PDOException $e) {
    die("数据库错误: " . $e->getMessage());
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $name = cleanInput($_POST['name'] ?? '');
    $barcode = cleanInput($_POST['barcode'] ?? '');
    $box_code = cleanInput($_POST['box_code'] ?? '');
    $purchase_price = cleanInput($_POST['purchase_price'] ?? '');
    $single_pack_price = cleanInput($_POST['single_pack_price'] ?? '');
    $delete_image = isset($_POST['delete_image']);
    $image_url = $item['image_url'];

    // 验证必填字段
    if (empty($name)) {
        $error = "香烟名称不能为空";
    }

    // 处理图片删除
    if ($delete_image && !empty($image_url) && file_exists("../$image_url")) {
        unlink("../$image_url");
        $image_url = '';
    }

    // 处理新图片上传
    if (isset($_FILES['new_image']) && $_FILES['new_image']['error'] === UPLOAD_ERR_OK) {
        $upload_result = handleImageUpload($_FILES['new_image']);
        if ($upload_result['success']) {
            // 删除旧图片
            if (!empty($image_url) && file_exists("../$image_url")) {
                unlink("../$image_url");
            }
            $image_url = $upload_result['path'];
        } else {
            $error = $upload_result['message'];
        }
    }

    // 如果没有错误，更新数据
    if (!isset($error)) {
        try {
            $stmt = $pdo->prepare("UPDATE cigarettes SET 
                name = ?, 
                barcode = ?, 
                box_code = ?, 
                purchase_price = ?, 
                single_pack_price = ?, 
                image_url = ?
                WHERE id = ?");
            
            $stmt->execute([
                $name,
                empty($barcode) ? null : $barcode,
                empty($box_code) ? null : $box_code,
                empty($purchase_price) ? null : $purchase_price,
                empty($single_pack_price) ? null : $single_pack_price,
                empty($image_url) ? null : $image_url,
                $id
            ]);
            
            $success = "香烟数据更新成功！";
            // 重新获取更新后的数据
            $stmt = $pdo->prepare("SELECT * FROM cigarettes WHERE id = ?");
            $stmt->execute([$id]);
            $item = $stmt->fetch();
        } catch (PDOException $e) {
            $error = "数据库错误: " . $e->getMessage();
        }
    }
}

include_once '../includes/header.php';
?>

<div class="admin-container">
    <h1>编辑香烟数据</h1>
    
    <?php include '../includes/admin_nav.php'; ?>
    
    <?php if (isset($success)): ?>
        <div class="alert alert-success"><?php echo htmlspecialchars($success); ?></div>
    <?php endif; ?>
    
    <?php if (isset($error)): ?>
        <div class="alert alert-error"><?php echo htmlspecialchars($error); ?></div>
    <?php endif; ?>
    
    <form method="post" enctype="multipart/form-data" class="admin-form">
        <input type="hidden" name="id" value="<?php echo $item['id']; ?>">
        
        <div class="form-group">
            <label for="name">香烟名称 *</label>
            <input type="text" id="name" name="name" value="<?php echo htmlspecialchars($item['name']); ?>" required>
        </div>
        
        <div class="form-group">
            <label for="barcode">条码</label>
            <input type="text" id="barcode" name="barcode" value="<?php echo htmlspecialchars($item['barcode'] ?? ''); ?>">
        </div>
        
        <div class="form-group">
            <label for="box_code">盒码</label>
            <input type="text" id="box_code" name="box_code" value="<?php echo htmlspecialchars($item['box_code'] ?? ''); ?>">
        </div>
        
        <div class="form-group">
            <label for="purchase_price">进价 (元)</label>
            <input type="number" step="0.01" id="purchase_price" name="purchase_price" value="<?php echo htmlspecialchars($item['purchase_price'] ?? ''); ?>">
        </div>
        
        <div class="form-group">
            <label for="single_pack_price">单包价格 (元)</label>
            <input type="number" step="0.01" id="single_pack_price" name="single_pack_price" value="<?php echo htmlspecialchars($item['single_pack_price'] ?? ''); ?>">
        </div>
        
        <div class="form-group">
            <label>当前图片</label>
            <?php if (!empty($item['image_url'])): ?>
                <div class="current-image">
                    <img src="../<?php echo $item['image_url']; ?>" class="item-image">
                    <label class="checkbox-label">
                        <input type="checkbox" name="delete_image"> 删除这张图片
                    </label>
                </div>
            <?php else: ?>
                <p>没有图片</p>
            <?php endif; ?>
            
            <label for="new_image">上传新图片</label>
            <input type="file" id="new_image" name="new_image" accept="image/jpeg,image/png">
            <small class="form-text">支持JPEG/PNG格式，最大2MB</small>
        </div>
        
        <div class="form-actions">
            <button type="submit" class="btn btn-primary">保存更改</button>
            <a href="manage.php" class="btn btn-secondary">取消</a>
        </div>
    </form>
</div>

<?php
include_once '../includes/footer.php';
?>