<?php
require_once '../includes/auth.php';
require_once '../includes/db.php';
require_once '../includes/functions.php';

// 验证管理员登录
if (!isLoggedIn()) {
    header("Location: ../login.php");
    exit;
}

$page_title = "数据统计分析";
$is_admin_page = true;

// 获取统计周期参数
$period = isset($_GET['period']) ? cleanInput($_GET['period']) : 'month';
$valid_periods = ['day', 'week', 'month', 'year'];
if (!in_array($period, $valid_periods)) {
    $period = 'month';
}

try {
    // 1. 基本统计
    $total_items = $pdo->query("SELECT COUNT(*) FROM cigarettes")->fetchColumn();
    $total_with_barcode = $pdo->query("SELECT COUNT(*) FROM cigarettes WHERE barcode IS NOT NULL")->fetchColumn();
    $total_with_image = $pdo->query("SELECT COUNT(*) FROM cigarettes WHERE image_url IS NOT NULL")->fetchColumn();
    
    // 2. 价格分析
    $price_stats = $pdo->query("
        SELECT 
            MIN(single_pack_price) as min_price,
            MAX(single_pack_price) as max_price,
            AVG(single_pack_price) as avg_price,
            SUM(single_pack_price) as total_value
        FROM cigarettes
        WHERE single_pack_price IS NOT NULL
    ")->fetch();
    
    // 3. 按时间段的添加统计
    $time_series = [];
    switch ($period) {
        case 'day':
            $interval = '1 DAY';
            $format = 'Y-m-d';
            $sql_format = '%Y-%m-%d';
            break;
        case 'week':
            $interval = '1 WEEK';
            $format = 'Y-W';
            $sql_format = '%Y-%u';
            break;
        case 'year':
            $interval = '1 YEAR';
            $format = 'Y';
            $sql_format = '%Y';
            break;
        case 'month':
        default:
            $interval = '1 MONTH';
            $format = 'Y-m';
            $sql_format = '%Y-%m';
    }
    
    $time_series_data = $pdo->query("
        SELECT 
            DATE_FORMAT(created_at, '$sql_format') as period,
            COUNT(*) as count
        FROM cigarettes
        GROUP BY period
        ORDER BY period DESC
        LIMIT 12
    ")->fetchAll();
    
    // 4. 品牌统计
    $brand_stats = $pdo->query("
        SELECT 
            SUBSTRING_INDEX(name, '(', 1) as brand,
            COUNT(*) as count
        FROM cigarettes
        GROUP BY brand
        ORDER BY count DESC
        LIMIT 10
    ")->fetchAll();
    
} catch (PDOException $e) {
    die("数据库错误: " . $e->getMessage());
}

include_once '../includes/header.php';
?>

<div class="admin-container">
    <h1>数据统计分析</h1>
    
    <?php include '../includes/admin_nav.php'; ?>
    
    <div class="stats-period-selector">
        <h3>统计周期: 
            <a href="?period=day" class="<?= $period === 'day' ? 'active' : '' ?>">日</a> |
            <a href="?period=week" class="<?= $period === 'week' ? 'active' : '' ?>">周</a> |
            <a href="?period=month" class="<?= $period === 'month' ? 'active' : '' ?>">月</a> |
            <a href="?period=year" class="<?= $period === 'year' ? 'active' : '' ?>">年</a>
        </h3>
    </div>
    
    <div class="stats-grid">
        <!-- 基本信息统计 -->
        <div class="stats-card">
            <h3>基本信息</h3>
            <div class="stats-item">
                <span class="stats-label">总记录数:</span>
                <span class="stats-value"><?= number_format($total_items) ?></span>
            </div>
            <div class="stats-item">
                <span class="stats-label">有条码记录:</span>
                <span class="stats-value"><?= number_format($total_with_barcode) ?> (<?= round($total_with_barcode/$total_items*100, 1) ?>%)</span>
            </div>
            <div class="stats-item">
                <span class="stats-label">有图片记录:</span>
                <span class="stats-value"><?= number_format($total_with_image) ?> (<?= round($total_with_image/$total_items*100, 1) ?>%)</span>
            </div>
        </div>
        
        <!-- 价格统计 -->
        <div class="stats-card">
            <h3>价格分析</h3>
            <div class="stats-item">
                <span class="stats-label">最低单价:</span>
                <span class="stats-value">¥<?= number_format($price_stats['min_price'] ?? 0, 2) ?></span>
            </div>
            <div class="stats-item">
                <span class="stats-label">最高单价:</span>
                <span class="stats-value">¥<?= number_format($price_stats['max_price'] ?? 0, 2) ?></span>
            </div>
            <div class="stats-item">
                <span class="stats-label">平均单价:</span>
                <span class="stats-value">¥<?= number_format($price_stats['avg_price'] ?? 0, 2) ?></span>
            </div>
        </div>
        
        <!-- 时间序列统计 -->
        <div class="stats-card wide-card">
            <h3>添加趋势 (<?= $period === 'day' ? '每日' : ($period === 'week' ? '每周' : ($period === 'year' ? '每年' : '每月')) ?>)</h3>
            <div class="chart-container">
                <canvas id="timeSeriesChart"></canvas>
            </div>
            <table class="stats-table">
                <thead>
                    <tr>
                        <th>时间段</th>
                        <th>添加数量</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($time_series_data as $item): ?>
                    <tr>
                        <td><?= htmlspecialchars($item['period']) ?></td>
                        <td><?= htmlspecialchars($item['count']) ?></td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
        
        <!-- 品牌统计 -->
        <div class="stats-card wide-card">
            <h3>品牌分布 (前10)</h3>
            <div class="chart-container">
                <canvas id="brandChart"></canvas>
            </div>
            <table class="stats-table">
                <thead>
                    <tr>
                        <th>品牌</th>
                        <th>数量</th>
                        <th>占比</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($brand_stats as $item): ?>
                    <tr>
                        <td><?= htmlspecialchars($item['brand']) ?></td>
                        <td><?= htmlspecialchars($item['count']) ?></td>
                        <td><?= round($item['count']/$total_items*100, 1) ?>%</td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<!-- 引入Chart.js -->
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
document.addEventListener('DOMContentLoaded', function() {
    // 时间序列图表
    const timeCtx = document.getElementById('timeSeriesChart').getContext('2d');
    const timeChart = new Chart(timeCtx, {
        type: 'line',
        data: {
            labels: [<?php 
                echo implode(',', array_map(function($item) { 
                    return "'" . htmlspecialchars($item['period'], ENT_QUOTES) . "'"; 
                }, array_reverse($time_series_data))); 
            ?>],
            datasets: [{
                label: '添加数量',
                data: [<?php 
                    echo implode(',', array_map(function($item) { 
                        return $item['count']; 
                    }, array_reverse($time_series_data))); 
                ?>],
                backgroundColor: 'rgba(54, 162, 235, 0.2)',
                borderColor: 'rgba(54, 162, 235, 1)',
                borderWidth: 1,
                tension: 0.1
            }]
        },
        options: {
            responsive: true,
            scales: {
                y: {
                    beginAtZero: true
                }
            }
        }
    });
    
    // 品牌分布图表
    const brandCtx = document.getElementById('brandChart').getContext('2d');
    const brandChart = new Chart(brandCtx, {
        type: 'bar',
        data: {
            labels: [<?php 
                echo implode(',', array_map(function($item) { 
                    return "'" . htmlspecialchars($item['brand'], ENT_QUOTES) . "'"; 
                }, $brand_stats)); 
            ?>],
            datasets: [{
                label: '数量',
                data: [<?php 
                    echo implode(',', array_map(function($item) { 
                        return $item['count']; 
                    }, $brand_stats)); 
                ?>],
                backgroundColor: [
                    'rgba(255, 99, 132, 0.7)',
                    'rgba(54, 162, 235, 0.7)',
                    'rgba(255, 206, 86, 0.7)',
                    'rgba(75, 192, 192, 0.7)',
                    'rgba(153, 102, 255, 0.7)',
                    'rgba(255, 159, 64, 0.7)',
                    'rgba(199, 199, 199, 0.7)',
                    'rgba(83, 102, 255, 0.7)',
                    'rgba(40, 159, 64, 0.7)',
                    'rgba(210, 99, 132, 0.7)'
                ],
                borderColor: [
                    'rgba(255, 99, 132, 1)',
                    'rgba(54, 162, 235, 1)',
                    'rgba(255, 206, 86, 1)',
                    'rgba(75, 192, 192, 1)',
                    'rgba(153, 102, 255, 1)',
                    'rgba(255, 159, 64, 1)',
                    'rgba(199, 199, 199, 1)',
                    'rgba(83, 102, 255, 1)',
                    'rgba(40, 159, 64, 1)',
                    'rgba(210, 99, 132, 1)'
                ],
                borderWidth: 1
            }]
        },
        options: {
            responsive: true,
            scales: {
                y: {
                    beginAtZero: true
                }
            }
        }
    });
});
</script>

<?php
include_once '../includes/footer.php';
?>